#include <stdio.h>
#include <stdlib.h>

#include "tiffio.h"

static void WritePPM(const uint32* raster, uint32 w, uint32 h, int s)
{
    FILE* fout = stdout;
    int y;

    fprintf(fout, "P7\nWIDTH %u\nHEIGHT %u\nDEPTH 4\nMAXVAL 255\n"
            "TUPLTYPE RGB_ALPHA\nENDHDR\n", w, h);
    for (y = 0; y < (int)h; ++y) {
        (void)fwrite(raster + y * s, w, 4, fout);
    }
    fclose(fout);
}

main(int argc, char* argv[])
{
    TIFF* tif = TIFFOpen(argv[1], "r");
    if (tif) {
        uint32 w, h;
        size_t npixels;
        uint32* raster;
        
        TIFFGetField(tif, TIFFTAG_IMAGEWIDTH, &w);
        TIFFGetField(tif, TIFFTAG_IMAGELENGTH, &h);
        npixels = w * h;
        raster = (uint32*) _TIFFmalloc(npixels * sizeof (uint32));
        if (raster != NULL) {
            /*if (TIFFReadRGBAImage(tif, w, h, raster, 0)) {
               WritePPM(raster + npixels - w, w, h, -(int)w); 
            }*/
            if (TIFFReadRGBAImageOriented(tif, w, h, raster,
                                          ORIENTATION_TOPLEFT, 0)) {
               WritePPM(raster, w, h, (int)w); 
            }
            _TIFFfree(raster);
        }
        TIFFClose(tif);
    }
    exit(0);
}
