#include <stdio.h>
#include <stdlib.h>

#include "tiffio.h"

static void WritePPM(const uint32* raster, uint32 w, uint32 h, int s)
{
    FILE* fout = stdout;
    int y;

    fprintf(fout, "P7\nWIDTH %u\nHEIGHT %u\nDEPTH 4\nMAXVAL 255\n"
            "TUPLTYPE RGB_ALPHA\nENDHDR\n", w, h);
    for (y = 0; y < (int)h; ++y) {
        (void)fwrite(raster + y * s, w, 4, fout);
    }
    fclose(fout);
}

main(int argc, char* argv[])
{
    TIFF* tif = TIFFOpen(argv[1], "r");
    if (tif) {
        TIFFRGBAImage img;
        char emsg[1024];
        
        if (TIFFRGBAImageBegin(&img, tif, 0, emsg)) {
            size_t npixels;
            uint32* raster;
            
            npixels = img.width * img.height;
            raster = (uint32*) _TIFFmalloc(npixels * sizeof (uint32));
            if (raster != NULL) {
                if (TIFFRGBAImageGet(&img, raster, img.width, img.height)) {
                    WritePPM(raster + npixels - img.width, img.width,
                             img.height, -(int)img.width); 
                }
                _TIFFfree(raster);
            }
            TIFFRGBAImageEnd(&img);
        } else
            TIFFError(argv[1], emsg);
        TIFFClose(tif);
    }
    exit(0);
}
