#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "tiffio.h"

static void WritePPM(const uint32* raster, uint32 w, uint32 h, int s)
{
    FILE* fout = stdout;
    int y;

    fprintf(fout, "P7\nWIDTH %u\nHEIGHT %u\nDEPTH 4\nMAXVAL 255\n"
            "TUPLTYPE RGB_ALPHA\nENDHDR\n", w, h);
    for (y = 0; y < (int)h; ++y) {
        (void)fwrite(raster + y * s, w, 4, fout);
    }
    fclose(fout);
}

main(int argc, char* argv[])
{
    TIFF* tif = TIFFOpen(argv[1], "r");
    if (tif) {
        uint32 imagelength;
        tdata_t buf;
        uint32 row, w;
        size_t npixels;
        uint32* raster;
        
        TIFFGetField(tif, TIFFTAG_IMAGEWIDTH, &w);
        TIFFGetField(tif, TIFFTAG_IMAGELENGTH, &imagelength);
        npixels = w * imagelength;
        raster = (uint32*) _TIFFmalloc(npixels * sizeof (uint32));
        buf = _TIFFmalloc(TIFFScanlineSize(tif));
        for (row = 0; row < imagelength; row++)
        {
            TIFFReadScanline(tif, buf, row, 0);
            memcpy(raster + row * w, buf, w * sizeof(uint32));
        }
        WritePPM(raster, w, imagelength, (int)w); 
        _TIFFfree(buf);
        _TIFFfree(raster);
        TIFFClose(tif);
    }
}
